@@ -131,6 +131,8 @@ type Manager struct {
 	inhibitAutoQuitCount int32
 	autoQuitCountMu      sync.Mutex
 	lastoreUnitCacheMu   sync.Mutex
+
+	preUpgradeOSVersion string
 }
 
 /*
@@ -154,6 +156,14 @@ func NewManager(service *dbusutil.Service, b system.System, c *Config) *Manager
 		AutoClean:           c.AutoClean,
 		UpdateMode:          c.UpdateMode,
 	}
+	osVersionInfoMap, err := getOSVersionInfo()
+	if err != nil {
+		logger.Warning(err)
+	} else {
+		m.preUpgradeOSVersion = strings.Join(
+			[]string{osVersionInfoMap["MajorVersion"], osVersionInfoMap["MinorVersion"], osVersionInfoMap["OsBuild"]},
+			".")
+	}
 	sysBus := service.Conn()
 	m.apps = apps.NewApps(sysBus)
 	m.initAutoInstall(sysBus)
@@ -609,6 +619,7 @@ func (m *Manager) updateSource(needNotify bool, autoCheck bool) (*Job, error) {
 	if needNotify {
 		jobName = "+notify"
 	}
+	prepareUpdateSource()
 	m.jobManager.dispatch() // 解决 bug 59351问题（防止CreatJob获取到状态为end但是未被删除的job）
 	job, err := m.jobManager.CreateJob(jobName, system.UpdateSourceJobType, nil, nil)
 	m.do.Unlock()
@@ -1437,6 +1448,7 @@ type upgradePostContent struct {
 	UpgradeErrorMsg string   `json:"msg"`
 	TimeStamp       int64    `json:"timestamp"`
 	SourceUrl       []string `json:"sourceUrl"`
+	Version         string   `json:"version"`
 }
 
 const (
@@ -1449,9 +1461,21 @@ func (m *Manager) postSystemUpgradeMessage(upgradeStatus int, j *Job, updateType
 	m.inhibitAutoQuitCountAdd()
 	defer m.inhibitAutoQuitCountSub()
 	var upgradeErrorMsg string
+	var version string
 	if upgradeStatus == upgradeFailed {
 		upgradeErrorMsg = j.Description
+		version = m.preUpgradeOSVersion
+	} else {
+		infoMap, err := getOSVersionInfo()
+		if err != nil {
+			logger.Warning(err)
+		} else {
+			version = strings.Join(
+				[]string{infoMap["MajorVersion"], infoMap["MinorVersion"], infoMap["OsBuild"]},
+				".")
+		}
 	}
+
 	sn, err := getSN()
 	if err != nil {
 		logger.Warning(err)
@@ -1460,6 +1484,7 @@ func (m *Manager) postSystemUpgradeMessage(upgradeStatus int, j *Job, updateType
 	if err != nil {
 		logger.Warning(err)
 	}
+
 	sourceFilePath := system.GetCategorySourceMap()[updateType]
 	postContent := &upgradePostContent{
 		SerialNumber:    sn,
@@ -1468,6 +1493,7 @@ func (m *Manager) postSystemUpgradeMessage(upgradeStatus int, j *Job, updateType
 		UpgradeErrorMsg: upgradeErrorMsg,
 		TimeStamp:       time.Now().Unix(),
 		SourceUrl:       getUpgradeUrls(sourceFilePath),
+		Version:         version,
 	}
 	content, err := json.Marshal(postContent)
 	if err != nil {
@@ -1477,6 +1503,7 @@ func (m *Manager) postSystemUpgradeMessage(upgradeStatus int, j *Job, updateType
 	client := &http.Client{
 		Timeout: 4 * time.Second,
 	}
+	logger.Debug(postContent)
 	encryptMsg, err := EncryptMsg(content)
 	if err != nil {
 		logger.Warning(err)
@@ -1881,3 +1908,18 @@ func (m *Manager) handleOSSignal() {
 		}
 	}
 }
+
+func prepareUpdateSource() {
+	partialFilePaths := []string{
+		"/var/lib/apt/lists/partial",
+		"/var/lib/lastore/lists/partial",
+		"/var/cache/apt/archives/partial",
+		"/var/cache/lastore/archives/partial",
+	}
+	for _, partialFilePath := range partialFilePaths {
+		err := os.RemoveAll(partialFilePath)
+		if err != nil {
+			logger.Warning(err)
+		}
+	}
+}
